"""Subscription resource — plans, active subscriptions, and recurring payments."""

from __future__ import annotations

from typing import Any

from .._internal.http import AsyncHTTP, SyncHTTP


class Subscriptions:
    """Synchronous subscription operations."""

    def __init__(self, http: SyncHTTP):
        self._http = http

    def create_plan(
        self,
        name: str,
        amount: float,
        currency: str,
        interval: str,
        *,
        interval_count: int = 1,
        description: str | None = None,
        trial_days: int | None = None,
        metadata: dict[str, Any] | None = None,
    ) -> dict[str, Any]:
        payload: dict[str, Any] = {
            "name": name,
            "amount": amount,
            "currency": currency,
            "interval": interval,
            "interval_count": interval_count,
        }
        if description is not None:
            payload["description"] = description
        if trial_days is not None:
            payload["trial_days"] = trial_days
        if metadata is not None:
            payload["metadata"] = metadata
        return self._http.post("/merchants/me/subscription-plans", json=payload)

    def list_plans(self, *, page: int = 1, limit: int = 50) -> list[dict[str, Any]]:
        return self._http.get("/merchants/me/subscription-plans", params={"page": page, "limit": limit})

    def update_plan(self, plan_id: str, **fields: Any) -> dict[str, Any]:
        return self._http.patch(f"/merchants/me/subscription-plans/{plan_id}", json=fields)

    def delete_plan(self, plan_id: str) -> None:
        self._http.delete(f"/merchants/me/subscription-plans/{plan_id}")

    def list(self, *, status: str | None = None, page: int = 1, limit: int = 50) -> list[dict[str, Any]]:
        params: dict[str, Any] = {"page": page, "limit": limit}
        if status:
            params["status"] = status
        return self._http.get("/merchants/me/subscriptions", params=params)

    def cancel(self, subscription_id: str) -> dict[str, Any]:
        return self._http.post(f"/merchants/me/subscriptions/{subscription_id}/cancel")

    def stats(self) -> dict[str, Any]:
        return self._http.get("/merchants/me/subscriptions/stats")

    def list_payments(self, *, page: int = 1, limit: int = 50) -> list[dict[str, Any]]:
        return self._http.get("/merchants/me/subscription-payments", params={"page": page, "limit": limit})


class AsyncSubscriptions:
    """Async subscription operations."""

    def __init__(self, http: AsyncHTTP):
        self._http = http

    async def create_plan(
        self,
        name: str,
        amount: float,
        currency: str,
        interval: str,
        *,
        interval_count: int = 1,
        description: str | None = None,
        trial_days: int | None = None,
        metadata: dict[str, Any] | None = None,
    ) -> dict[str, Any]:
        payload: dict[str, Any] = {
            "name": name,
            "amount": amount,
            "currency": currency,
            "interval": interval,
            "interval_count": interval_count,
        }
        if description is not None:
            payload["description"] = description
        if trial_days is not None:
            payload["trial_days"] = trial_days
        if metadata is not None:
            payload["metadata"] = metadata
        return await self._http.post("/merchants/me/subscription-plans", json=payload)

    async def list_plans(self, *, page: int = 1, limit: int = 50) -> list[dict[str, Any]]:
        return await self._http.get("/merchants/me/subscription-plans", params={"page": page, "limit": limit})

    async def update_plan(self, plan_id: str, **fields: Any) -> dict[str, Any]:
        return await self._http.patch(f"/merchants/me/subscription-plans/{plan_id}", json=fields)

    async def delete_plan(self, plan_id: str) -> None:
        await self._http.delete(f"/merchants/me/subscription-plans/{plan_id}")

    async def list(self, *, status: str | None = None, page: int = 1, limit: int = 50) -> list[dict[str, Any]]:
        params: dict[str, Any] = {"page": page, "limit": limit}
        if status:
            params["status"] = status
        return await self._http.get("/merchants/me/subscriptions", params=params)

    async def cancel(self, subscription_id: str) -> dict[str, Any]:
        return await self._http.post(f"/merchants/me/subscriptions/{subscription_id}/cancel")

    async def stats(self) -> dict[str, Any]:
        return await self._http.get("/merchants/me/subscriptions/stats")

    async def list_payments(self, *, page: int = 1, limit: int = 50) -> list[dict[str, Any]]:
        return await self._http.get("/merchants/me/subscription-payments", params={"page": page, "limit": limit})



"""Payment link resource — create and manage hosted payment links."""

from __future__ import annotations

from typing import Any

from .._internal.http import AsyncHTTP, SyncHTTP


class PaymentLinks:
    """Synchronous payment link operations."""

    def __init__(self, http: SyncHTTP):
        self._http = http

    def create(
        self,
        amount: float,
        currency: str,
        *,
        title: str | None = None,
        description: str | None = None,
        redirect_url: str | None = None,
        metadata: dict[str, Any] | None = None,
    ) -> dict[str, Any]:
        payload: dict[str, Any] = {"amount": amount, "currency": currency}
        if title is not None:
            payload["title"] = title
        if description is not None:
            payload["description"] = description
        if redirect_url is not None:
            payload["redirect_url"] = redirect_url
        if metadata is not None:
            payload["metadata"] = metadata
        return self._http.post("/merchants/me/payment-links", json=payload)

    def list(self, *, page: int = 1, limit: int = 50) -> list[dict[str, Any]]:
        return self._http.get("/merchants/me/payment-links", params={"page": page, "limit": limit})

    def update(self, link_id: str, **fields: Any) -> dict[str, Any]:
        return self._http.patch(f"/merchants/me/payment-links/{link_id}", json=fields)

    def delete(self, link_id: str) -> None:
        self._http.delete(f"/merchants/me/payment-links/{link_id}")


class AsyncPaymentLinks:
    """Async payment link operations."""

    def __init__(self, http: AsyncHTTP):
        self._http = http

    async def create(
        self,
        amount: float,
        currency: str,
        *,
        title: str | None = None,
        description: str | None = None,
        redirect_url: str | None = None,
        metadata: dict[str, Any] | None = None,
    ) -> dict[str, Any]:
        payload: dict[str, Any] = {"amount": amount, "currency": currency}
        if title is not None:
            payload["title"] = title
        if description is not None:
            payload["description"] = description
        if redirect_url is not None:
            payload["redirect_url"] = redirect_url
        if metadata is not None:
            payload["metadata"] = metadata
        return await self._http.post("/merchants/me/payment-links", json=payload)

    async def list(self, *, page: int = 1, limit: int = 50) -> list[dict[str, Any]]:
        return await self._http.get("/merchants/me/payment-links", params={"page": page, "limit": limit})

    async def update(self, link_id: str, **fields: Any) -> dict[str, Any]:
        return await self._http.patch(f"/merchants/me/payment-links/{link_id}", json=fields)

    async def delete(self, link_id: str) -> None:
        await self._http.delete(f"/merchants/me/payment-links/{link_id}")



"""Team resource — manage merchant team members and invites."""

from __future__ import annotations

from typing import Any

from .._internal.http import AsyncHTTP, SyncHTTP


class Teams:
    """Synchronous team operations."""

    def __init__(self, http: SyncHTTP):
        self._http = http

    def get(self) -> dict[str, Any]:
        return self._http.get("/merchants/me/team")

    def my_role(self) -> dict[str, Any]:
        return self._http.get("/merchants/me/team/my-role")

    def invite(self, email: str, role: str) -> dict[str, Any]:
        return self._http.post("/merchants/me/team/invite", json={"email": email, "role": role})

    def revoke_invite(self, invite_id: str) -> dict[str, Any]:
        return self._http.post(f"/merchants/me/team/invite/{invite_id}/revoke")

    def update_role(self, member_id: str, role: str) -> dict[str, Any]:
        return self._http.patch(f"/merchants/me/team/{member_id}/role", json={"role": role})

    def remove(self, member_id: str) -> None:
        self._http.delete(f"/merchants/me/team/{member_id}")


class AsyncTeams:
    """Async team operations."""

    def __init__(self, http: AsyncHTTP):
        self._http = http

    async def get(self) -> dict[str, Any]:
        return await self._http.get("/merchants/me/team")

    async def my_role(self) -> dict[str, Any]:
        return await self._http.get("/merchants/me/team/my-role")

    async def invite(self, email: str, role: str) -> dict[str, Any]:
        return await self._http.post("/merchants/me/team/invite", json={"email": email, "role": role})

    async def revoke_invite(self, invite_id: str) -> dict[str, Any]:
        return await self._http.post(f"/merchants/me/team/invite/{invite_id}/revoke")

    async def update_role(self, member_id: str, role: str) -> dict[str, Any]:
        return await self._http.patch(f"/merchants/me/team/{member_id}/role", json={"role": role})

    async def remove(self, member_id: str) -> None:
        await self._http.delete(f"/merchants/me/team/{member_id}")



from .invoices import Invoices, AsyncInvoices
from .payouts import Payouts, AsyncPayouts
from .wallets import Wallets, AsyncWallets
from .swaps import Swaps, AsyncSwaps
from .webhooks import Webhooks
from .payment_links import PaymentLinks, AsyncPaymentLinks
from .subscriptions import Subscriptions, AsyncSubscriptions
from .teams import Teams, AsyncTeams

__all__ = [
    "Invoices", "AsyncInvoices",
    "Payouts", "AsyncPayouts",
    "Wallets", "AsyncWallets",
    "Swaps", "AsyncSwaps",
    "Webhooks",
    "PaymentLinks", "AsyncPaymentLinks",
    "Subscriptions", "AsyncSubscriptions",
    "Teams", "AsyncTeams",
]
